function [adj,adjn] = Probabilistic_Random_Geometric(nnodes,dim,p)

%% Watts-Strogatz Probabilistic Random Geometric Network
 % We apply the idea of Watts-Strogatz rewiring to a random geometric
 % graph in hopes of attaining a small world network.
% Create Random Geometric graph with edge weights inversly proportional to
% distance between vectors i,j chosen uniformly at random in [0,1]^dim.
% Then perform edge switching similar to Watts-Strogatz rewiring. 

% Kahle, M. (2011)  Random geometric complexes. Discrete & Computational
%  Geometry,45(3), 553--573. 
% 
% Watts, D.~J. & Strogatz, S.~H. (1998)  Collective dynamics of
%small-world networks. Nature, 393(6684), 440--442.

% For the classification of weighted networks, maximized small world
% propensity from Muldoon, S.~F., Bridgeford, E.~W. {\&} Bassett, D.~S. (2015)  Small-World
% Propensity in Weighted, Real-World Networks. {\em arXiv preprint
%	arXiv:1505.02194}.


% Inputs
    % nnodes = number of nodes for network
    % dim = dimension of vectors
    % p = probaility of edge getting rewired
    
% Outputs
    % adj = adjacency matrix with A_ij = 1/d(i,j) where d(i,j) is the
    % euclidean distance, with some edges switched to give "shortcuts".
    % adjn = adj since no noise needed

% Reference: Ann Sizemore, Chad Giusti and Danielle S. Bassett,
% Classification of weighted networks through mesoscale homological 
% features (arXiv:1512.06457 [math.CO]) (submitted)

coords = rand(nnodes,dim);        % Choose random points

D = pdist(coords);              % Calculate Euclidean distance
D = squareform(D);              % Rewrite distances into distance matrix D

adj = 1./D;                     % Order adjacency matrix by distance 
                                % giving closest points highest weight
   
adj(isinf(adj)) = 0;                                
nrw = 0;                              
%% Rewire!

for i = 1:nnodes
    for j = 1:nnodes
        if i~=j
            
        r1 = rand;
        if r1<p
            % Pick new neighbor
            newnode = randperm(nnodes,1);
            
            % Switch edge weights
            a = adj(i,j);
            b = adj(i,newnode);
            adj(i,newnode) = a;
            adj(i,j) = b;
            adj(newnode,i) = a;
            adj(j,i) = b;
            
            % For counting the number of edges rewired
            nrw = nrw+1;
        end
        
        end
    end
end


adjn = adj;






end

